==> pipewire-docs-0.3.1-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/mem_8c.js <==
var mem_8c =
[
    [ "mempool", "structmempool.html", "structmempool" ],
    [ "memblock", "structmemblock.html", "structmemblock" ],
    [ "mapping", "structmapping.html", "structmapping" ],
    [ "memmap", "structmemmap.html", "structmemmap" ],
    [ "F_ADD_SEALS", "mem_8c.html#a3c9cb62957637bb3b3a869cbbe5e4aaa", null ],
    [ "F_GET_SEALS", "mem_8c.html#a0d7e40a9933d11da2fc1b0b1b863eec3", null ],
    [ "F_LINUX_SPECIFIC_BASE", "mem_8c.html#a54af789ad65b83449d415dbfb7d39481", null ],
    [ "F_SEAL_GROW", "mem_8c.html#a6ae683cd27bb82613d1c025277b69b48", null ],
    [ "F_SEAL_SEAL", "mem_8c.html#a68a01fe6f7305883d5f15ddfd1ebfd84", null ],
    [ "F_SEAL_SHRINK", "mem_8c.html#a98ea0829a6ae8b9adb9910457f4ca4cd", null ],
    [ "F_SEAL_WRITE", "mem_8c.html#a82af8008b212e99dd3a8b8daa2138170", null ],
    [ "MFD_ALLOW_SEALING", "mem_8c.html#a1d9ebf7ab094a827cd93d1e49e81e8a0", null ],
    [ "MFD_CLOEXEC", "mem_8c.html#a3268e6d65db2950f67f6082946d16952", null ],
    [ "NAME", "mem_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "pw_mempool_emit", "mem_8c.html#aee8f104fd65b3d11fef242883a787657", null ],
    [ "pw_mempool_emit_added", "mem_8c.html#ad2d67640ddabf8a7f530053ebca34abf", null ],
    [ "pw_mempool_emit_destroy", "mem_8c.html#ad9bd7205a3e7a88320624ef7addbfe9f", null ],
    [ "pw_mempool_emit_removed", "mem_8c.html#a1eac736570d41ffac78ec7c5caa8ca25", null ],
    [ "USE_MEMFD", "mem_8c.html#aa3b33676b8bd10a4280ec5f9a4f86831", null ],
    [ "pw_memblock_map", "mem_8c.html#a3318c5821ce251c9c3c16145bed41647", null ],
    [ "pw_memmap_free", "mem_8c.html#ada787db75d4f0040104f59210fbcfdac", null ],
    [ "pw_mempool_add_listener", "mem_8c.html#a5c298052be6fe8f5f4ea78b4fe41733d", null ],
    [ "pw_mempool_clear", "mem_8c.html#a9e39d964e7ba4d39449cb8b569504a3e", null ],
    [ "pw_mempool_destroy", "mem_8c.html#ab253128cb2d2bc7ad5203d2b65e762c8", null ],
    [ "pw_mempool_find_fd", "mem_8c.html#a6d863d10f2d358484936fd382f55b9b5", null ],
    [ "pw_mempool_find_id", "mem_8c.html#a277a61f49a8c8e232bb3af723af1fb3f", null ],
    [ "pw_mempool_find_ptr", "mem_8c.html#a9cb98e289a2f39ad7874243e905d9daf", null ],
    [ "pw_mempool_find_tag", "mem_8c.html#af289ae70c84c5f467bf04371dac6d6fa", null ],
    [ "pw_mempool_import", "mem_8c.html#abfda07a34439c7edfc8c2cb7fe9576a3", null ],
    [ "pw_mempool_import_block", "mem_8c.html#ac19e242f78a043eb56e57009cf87623e", null ],
    [ "pw_mempool_import_map", "mem_8c.html#a21cda477fe5bf4681ccf6869acf96d20", null ],
    [ "pw_mempool_map_id", "mem_8c.html#a7066384a72de880e75a1b922d2d62dd2", null ],
    [ "pw_mempool_new", "mem_8c.html#ae5e42242439fef39fd696db151642513", null ],
    [ "pw_mempool_unref_id", "mem_8c.html#a5f75d7faa910a02718a9ecf3f9c4041c", null ]
];

==> pipewire-docs-0.3.19-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/mem_8c.js <==
var mem_8c =
[
    [ "mempool", "structmempool.html", "structmempool" ],
    [ "memblock", "structmemblock.html", "structmemblock" ],
    [ "mapping", "structmapping.html", "structmapping" ],
    [ "memmap", "structmemmap.html", "structmemmap" ],
    [ "F_ADD_SEALS", "mem_8c.html#a3c9cb62957637bb3b3a869cbbe5e4aaa", null ],
    [ "F_GET_SEALS", "mem_8c.html#a0d7e40a9933d11da2fc1b0b1b863eec3", null ],
    [ "F_LINUX_SPECIFIC_BASE", "mem_8c.html#a54af789ad65b83449d415dbfb7d39481", null ],
    [ "F_SEAL_GROW", "mem_8c.html#a6ae683cd27bb82613d1c025277b69b48", null ],
    [ "F_SEAL_SEAL", "mem_8c.html#a68a01fe6f7305883d5f15ddfd1ebfd84", null ],
    [ "F_SEAL_SHRINK", "mem_8c.html#a98ea0829a6ae8b9adb9910457f4ca4cd", null ],
    [ "F_SEAL_WRITE", "mem_8c.html#a82af8008b212e99dd3a8b8daa2138170", null ],
    [ "MFD_ALLOW_SEALING", "mem_8c.html#a1d9ebf7ab094a827cd93d1e49e81e8a0", null ],
    [ "MFD_CLOEXEC", "mem_8c.html#a3268e6d65db2950f67f6082946d16952", null ],
    [ "NAME", "mem_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "pw_mempool_emit", "mem_8c.html#aee8f104fd65b3d11fef242883a787657", null ],
    [ "pw_mempool_emit_added", "mem_8c.html#ad2d67640ddabf8a7f530053ebca34abf", null ],
    [ "pw_mempool_emit_destroy", "mem_8c.html#ad9bd7205a3e7a88320624ef7addbfe9f", null ],
    [ "pw_mempool_emit_removed", "mem_8c.html#a1eac736570d41ffac78ec7c5caa8ca25", null ],
    [ "pw_memblock_map", "mem_8c.html#a3318c5821ce251c9c3c16145bed41647", null ],
    [ "pw_memmap_free", "mem_8c.html#ada787db75d4f0040104f59210fbcfdac", null ],
    [ "pw_mempool_add_listener", "mem_8c.html#a5c298052be6fe8f5f4ea78b4fe41733d", null ],
    [ "pw_mempool_clear", "mem_8c.html#a9e39d964e7ba4d39449cb8b569504a3e", null ],
    [ "pw_mempool_destroy", "mem_8c.html#ab253128cb2d2bc7ad5203d2b65e762c8", null ],
    [ "pw_mempool_find_fd", "mem_8c.html#a6d863d10f2d358484936fd382f55b9b5", null ],
    [ "pw_mempool_find_id", "mem_8c.html#a277a61f49a8c8e232bb3af723af1fb3f", null ],
    [ "pw_mempool_find_ptr", "mem_8c.html#a9cb98e289a2f39ad7874243e905d9daf", null ],
    [ "pw_mempool_find_tag", "mem_8c.html#af289ae70c84c5f467bf04371dac6d6fa", null ],
    [ "pw_mempool_import", "mem_8c.html#abfda07a34439c7edfc8c2cb7fe9576a3", null ],
    [ "pw_mempool_import_block", "mem_8c.html#ac19e242f78a043eb56e57009cf87623e", null ],
    [ "pw_mempool_import_map", "mem_8c.html#a21cda477fe5bf4681ccf6869acf96d20", null ],
    [ "pw_mempool_map_id", "mem_8c.html#a7066384a72de880e75a1b922d2d62dd2", null ],
    [ "pw_mempool_new", "mem_8c.html#ae5e42242439fef39fd696db151642513", null ],
    [ "pw_mempool_remove_id", "mem_8c.html#a4795146fb79f58f2277d535f71bdea34", null ]
];
